==> dart_blocks-0.0.50.tar.gz: lib/os_mobile_blocks/user_block_cupertino/AuthPage/LoginPage/login_page.dart <==
import 'package:dart_blocks/os_mobile_blocks/components/text_field_decoration.dart';
import 'package:dart_blocks/os_mobile_blocks/softcorp_client.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

class LoginPage extends StatelessWidget {
  LoginPage({
    Key? key,
    required this.loginButtonText,
    required this.emailHint,
    required this.passwordHint,
    required this.details,
    required this.onLogin,
    required this.logo,
    required this.title,
    required this.primaryColor,
    required this.secondaryColor,
    required this.createdBy,
    required this.background,
  }) : super(key: key);

  final Widget loginButtonText;
  final BoxDecoration background;
  final Color primaryColor;
  final Color secondaryColor;
  final String emailHint;
  final String passwordHint;
  final Widget details;
  final Widget logo;
  final Widget createdBy;
  final Widget title;
  final Function onLogin;

  final emailController = TextEditingController();
  final passwordController = TextEditingController();

  @override
  Widget build(BuildContext context) {
    return CupertinoPageScaffold(
      resizeToAvoidBottomInset: true,
      navigationBar: CupertinoNavigationBar(
        automaticallyImplyMiddle: true,
        backgroundColor: Colors.transparent,
        leading: Icon(
          Icons.arrow_back_ios,
          color: primaryColor,
        ),
        border: null,
        middle: title,
      ),
      child: Container(
        decoration: background,
        child: Padding(
          padding: const EdgeInsets.all(20),
          child: Column(
            children: <Widget>[
              const SizedBox(
                height: 100,
              ),
              details,
              const SizedBox(
                height: 30,
              ),
              logo,
              const SizedBox(
                height: 30,
              ),
              SizedBox(
                height: 40,
                child: CupertinoTextField(
                  decoration: textFieldDecoration(primaryColor),
                  controller: emailController,
                  placeholder: emailHint,
                  keyboardType: TextInputType.emailAddress,
                ),
              ),
              const SizedBox(
                height: 15,
              ),
              SizedBox(
                height: 40,
                child: CupertinoTextField(
                  decoration: textFieldDecoration(primaryColor),
                  controller: passwordController,
                  obscureText: true,
                  placeholder: passwordHint,
                  keyboardType: TextInputType.text,
                  maxLength: 80,
                ),
              ),
              const SizedBox(
                height: 30,
              ),
              CupertinoButton(
                color: primaryColor,
                onPressed: () {
                  if (emailController.text.isEmpty) {
                    showCupertinoDialog(
                        context: context,
                        builder: (context) {
                          return CupertinoAlertDialog(
                            title: const Text('Missing Email'),
                            content: const Text(
                                'Please provide an email to sign in'),
                            actions: <Widget>[
                              TextButton(
                                  onPressed: () {
                                    Navigator.of(context).pop();
                                  },
                                  child: const Text('okay'))
                            ],
                          );
                        });
                    return;
                  } else if (passwordController.text.isEmpty) {
                    showCupertinoDialog(
                        context: context,
                        builder: (context) {
                          return CupertinoAlertDialog(
                            title: const Text('Missing Password'),
                            content: const Text(
                                'Please provide a password in order to sign in'),
                            actions: <Widget>[
                              TextButton(
                                  onPressed: () {
                                    Navigator.of(context).pop();
                                  },
                                  child: const Text('okay'))
                            ],
                          );
                        });
                    return;
                  }
                  SoftcorpClient.userBlock
                      .login(
                          password: passwordController.text,
                          email: emailController.text)
                      .catchError((err) => {
                            passwordController.text = "",
                            emailController.text = "",
                            showCupertinoDialog(
                                context: context,
                                builder: (context) {
                                  return CupertinoAlertDialog(
                                    title:
                                        const Text('Invalid email or password'),
                                    content: const Text(
                                        'An error occurred. Your email or password is probably incorrect.'),
                                    actions: <Widget>[
                                      TextButton(
                                          onPressed: () {
                                            Navigator.of(context).pop();
                                          },
                                          child: const Text('okay'))
                                    ],
                                  );
                                })
                          })
                      .then((user) => {onLogin()});
                },
                child: loginButtonText,
              ),
              const SizedBox(
                height: 10,
              ),
              CupertinoButton(
                child: Text(
                  "Forgot your password?",
                  style: TextStyle(
                    color: primaryColor,
                  ),
                ),
                onPressed: () {},
              ),
              const Spacer(),
              createdBy,
            ],
          ),
        ),
      ),
    );
  }
}

==> dart_blocks-0.0.51.tar.gz: lib/os_mobile_blocks/user_block_cupertino/AuthPage/LoginPage/login_page.dart <==
import 'package:dart_blocks/os_mobile_blocks/components/text_field_decoration.dart';
import 'package:dart_blocks/os_mobile_blocks/softcorp_client.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

class LoginPage extends StatelessWidget {
  LoginPage({
    Key? key,
    required this.loginButtonText,
    required this.emailHint,
    required this.passwordHint,
    required this.details,
    required this.onLogin,
    required this.logo,
    required this.title,
    required this.primaryColor,
    required this.secondaryColor,
    required this.createdBy,
    required this.background,
  }) : super(key: key);

  final Widget loginButtonText;
  final BoxDecoration background;
  final Color primaryColor;
  final Color secondaryColor;
  final String emailHint;
  final String passwordHint;
  final Widget details;
  final Widget logo;
  final Widget createdBy;
  final Widget title;
  final Function onLogin;

  final emailController = TextEditingController();
  final passwordController = TextEditingController();

  @override
  Widget build(BuildContext context) {
    return CupertinoPageScaffold(
      resizeToAvoidBottomInset: true,
      navigationBar: CupertinoNavigationBar(
        automaticallyImplyMiddle: true,
        backgroundColor: Colors.transparent,
        leading: Icon(
          Icons.arrow_back_ios,
          color: primaryColor,
        ),
        border: null,
        middle: title,
      ),
      child: Container(
        decoration: background,
        child: Padding(
          padding: const EdgeInsets.all(20),
          child: Column(
            children: <Widget>[
              const SizedBox(
                height: 100,
              ),
              details,
              const SizedBox(
                height: 30,
              ),
              logo,
              const SizedBox(
                height: 30,
              ),
              SizedBox(
                height: 40,
                child: CupertinoTextField(
                  decoration: textFieldDecoration(primaryColor.withOpacity(0.7)),
                  controller: emailController,
                  placeholder: emailHint,
                  keyboardType: TextInputType.emailAddress,
                ),
              ),
              const SizedBox(
                height: 15,
              ),
              SizedBox(
                height: 40,
                child: CupertinoTextField(
                  decoration: textFieldDecoration(primaryColor.withOpacity(0.7)),
                  controller: passwordController,
                  obscureText: true,
                  placeholder: passwordHint,
                  keyboardType: TextInputType.text,
                  maxLength: 80,
                ),
              ),
              const SizedBox(
                height: 30,
              ),
              CupertinoButton(
                color: primaryColor,
                onPressed: () {
                  if (emailController.text.isEmpty) {
                    showCupertinoDialog(
                        context: context,
                        builder: (context) {
                          return CupertinoAlertDialog(
                            title: const Text('Missing Email'),
                            content: const Text(
                                'Please provide an email to sign in'),
                            actions: <Widget>[
                              TextButton(
                                  onPressed: () {
                                    Navigator.of(context).pop();
                                  },
                                  child: const Text('okay'))
                            ],
                          );
                        });
                    return;
                  } else if (passwordController.text.isEmpty) {
                    showCupertinoDialog(
                        context: context,
                        builder: (context) {
                          return CupertinoAlertDialog(
                            title: const Text('Missing Password'),
                            content: const Text(
                                'Please provide a password in order to sign in'),
                            actions: <Widget>[
                              TextButton(
                                  onPressed: () {
                                    Navigator.of(context).pop();
                                  },
                                  child: const Text('okay'))
                            ],
                          );
                        });
                    return;
                  }
                  SoftcorpClient.userBlock
                      .login(
                          password: passwordController.text,
                          email: emailController.text)
                      .catchError((err) => {
                            passwordController.text = "",
                            emailController.text = "",
                            showCupertinoDialog(
                                context: context,
                                builder: (context) {
                                  return CupertinoAlertDialog(
                                    title:
                                        const Text('Invalid email or password'),
                                    content: const Text(
                                        'An error occurred. Your email or password is probably incorrect.'),
                                    actions: <Widget>[
                                      TextButton(
                                          onPressed: () {
                                            Navigator.of(context).pop();
                                          },
                                          child: const Text('okay'))
                                    ],
                                  );
                                })
                          })
                      .then((user) => {onLogin()});
                },
                child: loginButtonText,
              ),
              const SizedBox(
                height: 10,
              ),
              CupertinoButton(
                child: Text(
                  "Forgot your password?",
                  style: TextStyle(
                    color: primaryColor,
                  ),
                ),
                onPressed: () {},
              ),
              const Spacer(),
              createdBy,
            ],
          ),
        ),
      ),
    );
  }
}
